@@ -36,7 +36,6 @@
 #include "PeerInitiateConnectionCommand.h"
 #include "message.h"
 #include "DownloadEngine.h"
-#include "BtContext.h"
 #include "PeerStorage.h"
 #include "PieceStorage.h"
 #include "BtRuntime.h"
@@ -48,6 +47,7 @@
 #include "SocketCore.h"
 #include "BtAnnounce.h"
 #include "RequestGroup.h"
+#include "DownloadContext.h"
 
 namespace aria2 {
 
@@ -55,15 +55,12 @@ ActivePeerConnectionCommand::ActivePeerConnectionCommand
 (int cuid,
  RequestGroup* requestGroup,
  DownloadEngine* e,
- const BtContextHandle& btContext,
  time_t interval)
   :
   Command(cuid),
   _requestGroup(requestGroup),
-  _btContext(btContext),
   interval(interval),
   e(e),
-  _thresholdSpeed(e->option->getAsInt(PREF_BT_REQUEST_PEER_SPEED_LIMIT)),
   _numNewConnection(5)
 {
   _requestGroup->increaseNumCommand();
@@ -84,9 +81,10 @@ bool ActivePeerConnectionCommand::execute() {
     const unsigned int maxDownloadLimit =
       _requestGroup->getMaxDownloadSpeedLimit();
     const unsigned int maxUploadLimit = _requestGroup->getMaxUploadSpeedLimit();
-    unsigned int thresholdSpeed = _thresholdSpeed;
+    unsigned int thresholdSpeed =
+      _requestGroup->getOption()->getAsInt(PREF_BT_REQUEST_PEER_SPEED_LIMIT);
     if(maxDownloadLimit > 0) {
-      thresholdSpeed = std::min(maxDownloadLimit, _thresholdSpeed);
+      thresholdSpeed = std::min(maxDownloadLimit, thresholdSpeed);
     }
     if(// for seeder state
        (_pieceStorage->downloadFinished() && _btRuntime->lessThanMaxPeers() &&
@@ -130,7 +128,7 @@ void ActivePeerConnectionCommand::connectToPeer(const PeerHandle& peer)
   peer->usedBy(e->newCUID());
   PeerInitiateConnectionCommand* command =
     new PeerInitiateConnectionCommand(peer->usedBy(), _requestGroup, peer, e,
-				      _btContext, _btRuntime);
+				      _btRuntime);
   command->setPeerStorage(_peerStorage);
   command->setPieceStorage(_pieceStorage);
   e->commands.push_back(command);
