@@ -43,7 +43,7 @@
 #include "prefs.h"
 #include "Util.h"
 #include "message.h"
-#include "SingleFileDownloadContext.h"
+#include "DownloadContext.h"
 #include "MetalinkHelper.h"
 #include "BinaryStream.h"
 #include "MemoryBufferPreDownloadHandler.h"
@@ -169,12 +169,14 @@ Metalink2RequestGroup::createRequestGroup
     if(itr != entry->resources.end()) {
       std::deque<std::string> uris;
       uris.push_back((*itr)->url);
-      torrentRg.reset(new RequestGroup(option, uris));
-      SharedHandle<SingleFileDownloadContext> dctx
-	(new SingleFileDownloadContext(option->getAsInt(PREF_SEGMENT_SIZE),
-				       0,
-				       A2STR::NIL));
+      torrentRg.reset(new RequestGroup(option));
+      SharedHandle<DownloadContext> dctx
+	(new DownloadContext(option->getAsInt(PREF_SEGMENT_SIZE),
+			     0,
+			     A2STR::NIL));
+      // Since torrent is downloaded in memory, setting dir has no effect.
       //dctx->setDir(_option->get(PREF_DIR));
+      dctx->getFirstFileEntry()->setUris(uris);
       torrentRg->setDownloadContext(dctx);
       torrentRg->clearPreDowloadHandler();
       torrentRg->clearPostDowloadHandler();
@@ -195,7 +197,7 @@ Metalink2RequestGroup::createRequestGroup
     std::deque<std::string> uris;
     std::for_each(entry->resources.begin(), entry->resources.end(),
 		  AccumulateNonP2PUrl(uris));
-    SharedHandle<RequestGroup> rg(new RequestGroup(option, uris));
+    SharedHandle<RequestGroup> rg(new RequestGroup(option));
     // If piece hash is specified in the metalink,
     // make segment size equal to piece hash size.
     size_t pieceLength;
@@ -208,13 +210,16 @@ Metalink2RequestGroup::createRequestGroup
 #else
     pieceLength = option->getAsInt(PREF_SEGMENT_SIZE);
 #endif // ENABLE_MESSAGE_DIGEST
-    SharedHandle<SingleFileDownloadContext> dctx
-      (new SingleFileDownloadContext
+    SharedHandle<DownloadContext> dctx
+      (new DownloadContext
        (pieceLength,
 	entry->getLength(),
-	A2STR::NIL,
 	strconcat(option->get(PREF_DIR), "/", entry->file->getPath())));
     dctx->setDir(option->get(PREF_DIR));
+    dctx->getFirstFileEntry()->setUris(uris);
+    if(option->getAsBool(PREF_METALINK_ENABLE_UNIQUE_PROTOCOL)) {
+      dctx->getFirstFileEntry()->disableSingleHostMultiConnection();
+    }
 #ifdef ENABLE_MESSAGE_DIGEST
     if(entry->chunkChecksum.isNull()) {
       if(!entry->checksum.isNull()) {
@@ -222,7 +227,8 @@ Metalink2RequestGroup::createRequestGroup
 	dctx->setChecksumHashAlgo(entry->checksum->getAlgo());
       }
     } else {
-      dctx->setPieceHashes(entry->chunkChecksum->getChecksums());
+      dctx->setPieceHashes(entry->chunkChecksum->getChecksums().begin(),
+			   entry->chunkChecksum->getChecksums().end());
       dctx->setPieceHashAlgo(entry->chunkChecksum->getAlgo());
     }
 #endif // ENABLE_MESSAGE_DIGEST
@@ -233,8 +239,6 @@ Metalink2RequestGroup::createRequestGroup
        option->getAsInt(PREF_METALINK_SERVERS) :
        std::min(option->getAsInt(PREF_METALINK_SERVERS),
 		static_cast<int32_t>(entry->maxConnections)));
-    // In metalink, multi connection to a single host is not allowed by default.
-    rg->setSingleHostMultiConnectionEnabled(!option->getAsBool(PREF_METALINK_ENABLE_UNIQUE_PROTOCOL));
     // remove "metalink" from Accept Type list to avoid loop in tranparent
     // metalink
     rg->removeAcceptType(RequestGroup::ACCEPT_METALINK);
