@@ -54,6 +54,7 @@
 #include "File.h"
 #include "Netrc.h"
 #include "AuthConfigFactory.h"
+#include "DownloadContext.h"
 #ifdef ENABLE_SSL
 # include "SocketCore.h"
 # include "TLSContext.h"
@@ -99,29 +100,24 @@ void MultiUrlRequestInfo::printMessageForContinue()
 	      << "\n";
 }
 
-DownloadResult::RESULT MultiUrlRequestInfo::execute()
+downloadresultcode::RESULT MultiUrlRequestInfo::execute()
 {
-  DownloadResult::RESULT returnValue = DownloadResult::FINISHED;
+  downloadresultcode::RESULT returnValue = downloadresultcode::FINISHED;
   try {
     DownloadEngineHandle e =
       DownloadEngineFactory().newDownloadEngine(_option.get(), _requestGroups);
 
-    try {
-      if(!_option->blank(PREF_LOAD_COOKIES)) {
-	File cookieFile(_option->get(PREF_LOAD_COOKIES));
-	if(cookieFile.isFile()) {
-	  e->getCookieStorage()->load(_option->get(PREF_LOAD_COOKIES));
-	} else {
-	  _logger->error(MSG_LOADING_COOKIE_FAILED,
-			 _option->get(PREF_LOAD_COOKIES).c_str());
-	}
+    if(!_option->blank(PREF_LOAD_COOKIES)) {
+      File cookieFile(_option->get(PREF_LOAD_COOKIES));
+      if(cookieFile.isFile()) {
+	e->getCookieStorage()->load(_option->get(PREF_LOAD_COOKIES));
+      } else {
+	_logger->error(MSG_LOADING_COOKIE_FAILED,
+		       _option->get(PREF_LOAD_COOKIES).c_str());
       }
-    } catch(RecoverableException& e) {
-      _logger->error(EX_EXCEPTION_CAUGHT, e);
     }
 
-    SharedHandle<AuthConfigFactory> authConfigFactory
-      (new AuthConfigFactory(_option.get()));
+    SharedHandle<AuthConfigFactory> authConfigFactory(new AuthConfigFactory());
     File netrccf(_option->get(PREF_NETRC_PATH));
     if(!_option->getAsBool(PREF_NO_NETRC) && netrccf.isFile()) {
       mode_t mode = netrccf.mode();
@@ -144,10 +140,7 @@ DownloadResult::RESULT MultiUrlRequestInfo::execute()
 				   _option->get(PREF_PRIVATE_KEY));
     }
     if(!_option->blank(PREF_CA_CERTIFICATE)) {
-      try {
-	tlsContext->addTrustedCACertFile(_option->get(PREF_CA_CERTIFICATE));
-      } catch(RecoverableException& e) {
-	_logger->error(EX_EXCEPTION_CAUGHT, e);
+      if(!tlsContext->addTrustedCACertFile(_option->get(PREF_CA_CERTIFICATE))) {
 	_logger->warn(MSG_WARN_NO_CA_CERT);
       }
     } else if(_option->getAsBool(PREF_CHECK_CERTIFICATE)) {
@@ -183,11 +176,7 @@ DownloadResult::RESULT MultiUrlRequestInfo::execute()
     e->run();
     
     if(!_option->blank(PREF_SAVE_COOKIES)) {
-      try {
-	e->getCookieStorage()->saveNsFormat(_option->get(PREF_SAVE_COOKIES));
-      } catch(RecoverableException& e) {
-	_logger->error(EX_EXCEPTION_CAUGHT, e);
-      }
+      e->getCookieStorage()->saveNsFormat(_option->get(PREF_SAVE_COOKIES));
     }
 
     std::string serverStatOf = _option->get(PREF_SERVER_STAT_OF);
@@ -200,9 +189,9 @@ DownloadResult::RESULT MultiUrlRequestInfo::execute()
     RequestGroupMan::DownloadStat s = e->_requestGroupMan->getDownloadStat();
     if(!s.allCompleted()) {
       printMessageForContinue();
-      if(s.getLastErrorResult() == DownloadResult::FINISHED &&
+      if(s.getLastErrorResult() == downloadresultcode::FINISHED &&
 	 s.getInProgress() > 0) {
-	returnValue = DownloadResult::IN_PROGRESS;
+	returnValue = downloadresultcode::IN_PROGRESS;
       } else {
 	returnValue = s.getLastErrorResult();
       }
