@@ -47,6 +47,7 @@
 #include "A2STR.h"
 #include "a2functional.h"
 #include "array_fun.h"
+#include "OptionHandlerFactory.h"
 
 namespace aria2 {
 
@@ -70,7 +71,11 @@ static void putOptions(struct option* longOpts, int* plopt,
 {
   for(; first != last; ++first) {
     if(!(*first)->isHidden()) {
+#ifdef HAVE_OPTION_CONST_NAME
       (*longOpts).name = (*first)->getName().c_str();
+#else // !HAVE_OPTION_CONST_NAME
+      (*longOpts).name = strdup((*first)->getName().c_str());
+#endif // !HAVE_OPTION_CONST_NAME
       switch((*first)->getArgType()) {
       case OptionHandler::REQ_ARG:
 	(*longOpts).has_arg = required_argument;
@@ -141,7 +146,7 @@ void OptionParser::parseArg
       op = findByShortName(c);
     }
     if(op.isNull()) {
-      throw FatalException("Failed to parse command-line options.");
+      throw DL_ABORT_EX("Failed to parse command-line options.");
     }
     out << op->getName() << "=";
     if(optarg) {
@@ -337,4 +342,15 @@ OptionParser::getOptionHandlers() const
   return _optionHandlers;
 }
 
+SharedHandle<OptionParser> OptionParser::_optionParser;
+
+SharedHandle<OptionParser> OptionParser::getInstance()
+{
+  if(_optionParser.isNull()) {
+    _optionParser.reset(new OptionParser());
+    _optionParser->setOptionHandlers(OptionHandlerFactory::createOptionHandlers());
+  }
+  return _optionParser;
+}
+
 } // namespace aria2
