@@ -50,7 +50,6 @@ public:
   enum STATUS {
     IDLE,
     ACTIVE,
-    REQUEST_IDLE,
   };
 private:
   cuid_t cuid;
@@ -158,10 +157,6 @@ public:
     status = PeerStat::IDLE;
   }
 
-  void requestIdle() {
-    status = PeerStat::REQUEST_IDLE;
-  }
-
   const Time& getDownloadStartTime() const {
     return downloadStartTime;
   }
@@ -193,6 +188,11 @@ public:
   {
     return _sessionUploadLength;
   }
+
+  void addSessionDownloadLength(uint64_t length)
+  {
+    _sessionDownloadLength += length;
+  }
 };
 
 typedef SharedHandle<PeerStat> PeerStatHandle;
