@@ -101,7 +101,8 @@ public:
   /**
    * Returns a missing piece if available. Otherwise returns 0;
    */
-  virtual SharedHandle<Piece> getMissingPiece();
+  virtual SharedHandle<Piece> getSparseMissingUnusedPiece
+  (const unsigned char* ignoreBitfield, size_t length);
 
   /**
    * Returns a missing piece whose index is index.
