@@ -2,17 +2,11 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-#include "File.h"
-#include "prefs.h"
-#include "Util.h"
-#include "SingleFileDownloadContext.h"
+#include "DownloadContext.h"
 #include "UnknownLengthPieceStorage.h"
 #include "DefaultPieceStorage.h"
 #include "Segment.h"
 #include "Option.h"
-#include "FileEntry.h"
-#include "MockPieceStorage.h"
-#include "PeerStat.h"
 #include "PieceSelector.h"
 
 namespace aria2 {
@@ -22,8 +16,8 @@ class SegmentManTest:public CppUnit::TestFixture {
   CPPUNIT_TEST_SUITE(SegmentManTest);
   CPPUNIT_TEST(testNullBitfield);
   CPPUNIT_TEST(testCompleteSegment);
-  CPPUNIT_TEST(testGetPeerStat);
-  CPPUNIT_TEST(testGetSegment_segmentForward);
+  CPPUNIT_TEST(testGetSegment_sameFileEntry);
+  CPPUNIT_TEST(testRegisterPeerStat);
   CPPUNIT_TEST_SUITE_END();
 private:
 
@@ -34,7 +28,8 @@ public:
   void testNullBitfield();
   void testCompleteSegment();
   void testGetPeerStat();
-  void testGetSegment_segmentForward();
+  void testGetSegment_sameFileEntry();
+  void testRegisterPeerStat();
 };
 
 
@@ -43,8 +38,8 @@ CPPUNIT_TEST_SUITE_REGISTRATION( SegmentManTest );
 void SegmentManTest::testNullBitfield()
 {
   Option op;
-  SharedHandle<SingleFileDownloadContext> dctx
-    (new SingleFileDownloadContext(0, 0, "aria2.tar.bz2"));
+  SharedHandle<DownloadContext> dctx
+    (new DownloadContext(0, 0, "aria2.tar.bz2"));
   SharedHandle<UnknownLengthPieceStorage> ps
     (new UnknownLengthPieceStorage(dctx, &op));
   SegmentMan segmentMan(&op, dctx, ps);
@@ -68,8 +63,8 @@ void SegmentManTest::testCompleteSegment()
   Option op;
   size_t pieceLength = 1024*1024;
   uint64_t totalLength = 64*1024*1024;
-  SharedHandle<SingleFileDownloadContext> dctx
-    (new SingleFileDownloadContext(pieceLength, totalLength, "aria2.tar.bz2"));
+  SharedHandle<DownloadContext> dctx
+    (new DownloadContext(pieceLength, totalLength, "aria2.tar.bz2"));
   SharedHandle<DefaultPieceStorage> ps(new DefaultPieceStorage(dctx, &op));
 
   SegmentMan segmentMan(&op, dctx, ps);
@@ -89,64 +84,64 @@ void SegmentManTest::testCompleteSegment()
   CPPUNIT_ASSERT_EQUAL((size_t)2, segments[1]->getIndex());
 }
 
-void SegmentManTest::testGetPeerStat()
+void SegmentManTest::testGetSegment_sameFileEntry()
 {
   Option op;
-  size_t pieceLength = 1;
-  uint64_t totalLength = 1;
-  SharedHandle<SingleFileDownloadContext> dctx
-    (new SingleFileDownloadContext(pieceLength, totalLength, "aria2.tar.bz2"));
-  SharedHandle<PieceStorage> ps(new MockPieceStorage());
-  SegmentMan segmentMan(&op, dctx, ps);
+  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  dctx->setPieceLength(2);
+  SharedHandle<FileEntry> fileEntries[] = {
+    SharedHandle<FileEntry>(new FileEntry("file1", 3, 0)),
+    SharedHandle<FileEntry>(new FileEntry("file2", 6, 3)),
+    SharedHandle<FileEntry>(new FileEntry("file3", 1, 9))
+  };
+  dctx->setFileEntries(&fileEntries[0], &fileEntries[3]);
+  SharedHandle<DefaultPieceStorage> ps(new DefaultPieceStorage(dctx, &op));
+  SegmentMan segman(&op, dctx, ps);
 
-  CPPUNIT_ASSERT(segmentMan.getPeerStat(1).isNull());
-  SharedHandle<PeerStat> ps1(new PeerStat(1));
-  CPPUNIT_ASSERT(segmentMan.registerPeerStat(ps1));
-  {
-    SharedHandle<PeerStat> ps = segmentMan.getPeerStat(1);
-    CPPUNIT_ASSERT(!ps.isNull());
-    CPPUNIT_ASSERT_EQUAL(1, ps->getCuid());
-  }
-  // Duplicate registering is not allowed.
-  SharedHandle<PeerStat> ps1d(new PeerStat(1));
-  CPPUNIT_ASSERT(!segmentMan.registerPeerStat(ps1d));
+  std::deque<SharedHandle<Segment> > segments;
+  segman.getSegment(segments, 1, fileEntries[1], 4);
+  // See 3 segments are returned, not 4 because the part of file1 is
+  // not filled in segment#1
+  CPPUNIT_ASSERT_EQUAL((size_t)3, segments.size());
   
-  // See whether it can work on several entries.
-  SharedHandle<PeerStat> ps2(new PeerStat(2));
-  SharedHandle<PeerStat> ps3(new PeerStat(3));
-  CPPUNIT_ASSERT(segmentMan.registerPeerStat(ps3));
-  CPPUNIT_ASSERT(segmentMan.registerPeerStat(ps2));
-  {
-    SharedHandle<PeerStat> ps = segmentMan.getPeerStat(2);
-    CPPUNIT_ASSERT(!ps.isNull());
-    CPPUNIT_ASSERT_EQUAL(2, ps->getCuid());
-  }
+  SharedHandle<Segment> segmentNo1 = segman.getSegment(2, 1);
+  // Fill the part of file1 in segment#1
+  segmentNo1->updateWrittenLength(1);
+  segman.cancelSegment(2);
+
+  segman.cancelSegment(1);
+  segments.clear();
+  segman.getSegment(segments, 1, fileEntries[1], 4);
+  CPPUNIT_ASSERT_EQUAL((size_t)4, segments.size());
+
+  segman.cancelSegment(1);
+  SharedHandle<Segment> segmentNo4 = segman.getSegment(1, 4);
+  // Fill the part of file2 in segment#4
+  segmentNo4->updateWrittenLength(1);
+  segman.cancelSegment(1);
+
+  segments.clear();
+  segman.getSegment(segments, 1, fileEntries[1], 4);
+  // segment#4 is not returned because the part of file2 is filled.
+  CPPUNIT_ASSERT_EQUAL((size_t)3, segments.size());
 }
 
-void SegmentManTest::testGetSegment_segmentForward()
+void SegmentManTest::testRegisterPeerStat()
 {
   Option op;
-  size_t pieceLength = 1;
-  uint64_t totalLength = 1;
-  SharedHandle<SingleFileDownloadContext> dctx
-    (new SingleFileDownloadContext(pieceLength, totalLength, "aria2.tar.bz2"));
-  SharedHandle<PieceStorage> ps(new DefaultPieceStorage(dctx, &op));
-  SegmentMan segmentMan(&op, dctx, ps);
-
-  SharedHandle<Segment> segment = segmentMan.getSegment(1);
-  CPPUNIT_ASSERT(!segment.isNull());
-  CPPUNIT_ASSERT_EQUAL((size_t)0, segment->getIndex());
-
-  SharedHandle<PeerStat> cuid2_ps(new PeerStat(2));
-  CPPUNIT_ASSERT(segmentMan.registerPeerStat(cuid2_ps));
-
-  SharedHandle<Segment> segment_forwarded = segmentMan.getSegment(2);
-  CPPUNIT_ASSERT(!segment_forwarded.isNull());
-  CPPUNIT_ASSERT_EQUAL((size_t)0, segment_forwarded->getIndex());
-
-  // SegmentMan::getSegmetn(3) returns null because CUID#3's PeerStat is not
-  // registered and all segment(total 1 in this case) are used.
-  CPPUNIT_ASSERT(segmentMan.getSegment(3).isNull());
+  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  SharedHandle<DefaultPieceStorage> ps(new DefaultPieceStorage(dctx, &op));
+  SegmentMan segman(&op, dctx, ps);
+  
+  SharedHandle<PeerStat> p1(new PeerStat(0, "host1", "http"));
+  segman.registerPeerStat(p1);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, segman.getPeerStats().size());
+  SharedHandle<PeerStat> p2(new PeerStat(0, "host2", "http"));
+  segman.registerPeerStat(p2);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, segman.getPeerStats().size());
+  p2->downloadStart();
+  segman.registerPeerStat(p1);
+  CPPUNIT_ASSERT_EQUAL((size_t)2, segman.getPeerStats().size());
 }
 
 } // namespace aria2
